# GXT format definition

The `gxt` format (short for graph txt) contains as the first line the number of edges and then a list of edges (one line per edge). The only fields (in this order) are `src` and `dest` for edges. Node ids (and thus the src and dest in edges) have to be consecutive integers.
